#uptime[data-v-dc11558d]{color:var(--t-muted);font-size:9pt;text-align:center}.clock[data-v-dc11558d]{color:var(--t-fg)}.system-widget[data-v-dc11558d]{display:flex;flex-direction:column;align-items:center;padding:1px;border-bottom:1px solid var(--t-border)}
